import { defineConfig, normalizePath, Plugin, loadEnv } from "vite";
import vue from "@vitejs/plugin-vue";
import ViteComponents from "unplugin-vue-components/vite";
import { AntDesignVueResolver } from "unplugin-vue-components/resolvers";

const env = loadEnv("development", process.cwd(), "");

const path = require("path");

function mockDevLogin(): Plugin {
  return {
    name: "mockDevLogin",
    apply: "build",
    load(id) {
      if (id === normalizePath(path.resolve(__dirname, "src/devLogin.ts"))) {
        return `export const initLogin = () => {}`;
      }
    },
  };
}

// https://vitejs.dev/config/
export default defineConfig({
  base: env.VUE_APP_DEV_BASE_URL || undefined,
  plugins: [
    vue({
      reactivityTransform: true,
    }),
    ViteComponents({
      resolvers: [AntDesignVueResolver()],
      dts: true,
    }),
    mockDevLogin(),
  ],
  server: {
    port: 9000,
    // strictPort: true,
    fs: {
      strict: true,
      allow: ["./"],
    },
    proxy: {
      "/login": {
        target: env.VUE_APP_DEV_PROXY,
        changeOrigin: true,
      },
      "/mark": {
        target: env.VUE_APP_DEV_PROXY,
        changeOrigin: true,
      },
      "/admin": {
        target: env.VUE_APP_DEV_PROXY,
        changeOrigin: true,
      },
      "/api": {
        target: env.VUE_APP_DEV_PROXY,
        // changeOrigin: true,
      },
    },
  },
  resolve: {
    alias: [{ find: "@", replacement: path.resolve(__dirname, "./src") }],
    extensions: [".js", ".mjs", ".ts", ".vue", ".json", ".scss", ".css"],
  },
  build: {
    ssr: false,
    commonjsOptions: { include: [] },
  },
  optimizeDeps: {
    disabled: false,
  },
  // define: {
  //   __VUE_PROD_DEVTOOLS__: true, // no effect
  // },
});
